@@ -823,9 +823,6 @@ hildon_home_area_add (GtkContainer *area, GtkWidget *applet)
 
   priv = HILDON_HOME_AREA_GET_PRIVATE (area);
 
-  g_debug ("Adding Hildon Home applet %s",
-           hildon_desktop_item_get_id (HILDON_DESKTOP_ITEM (applet)));
-
   if (HILDON_DESKTOP_IS_HOME_ITEM (applet))
     {
       Layout   *layout = NULL;
@@ -1233,14 +1230,6 @@ hildon_home_area_expose (GtkWidget *widget,
 
   priv = HILDON_HOME_AREA_GET_PRIVATE (widget);
 
-#if 0
-  g_debug ("Got expose event on %i,%i %ix%i",
-           event->area.x,
-           event->area.y,
-           event->area.width,
-           event->area.height);
-#endif
-
   if (GTK_WIDGET_DRAWABLE (widget))
     {
       XRectangle                rectangle;
@@ -1350,14 +1339,6 @@ hildon_home_area_child_window_filter (GdkXEvent        *xevent,
           rect.width  = rects[i].width;
           rect.height = rects[i].height;
 
-#if 0
-          g_debug ("Got damage on %i, %i %ix%i",
-                   rect.x,
-                   rect.y,
-                   rect.width,
-                   rect.height);
-#endif
-
           gdk_window_invalidate_rect (GTK_WIDGET (area)->window,
                                       &rect,
                                       FALSE);
@@ -1668,8 +1649,6 @@ hildon_home_area_place (HildonHomeArea *area, GtkWidget *w)
 
   name = hildon_desktop_item_get_id (HILDON_DESKTOP_ITEM (w));
 
-  g_debug ("Placing: %s", name);
-
   priv = HILDON_HOME_AREA_GET_PRIVATE (area);
 
   area_rectangle = create_rectangle (0,
@@ -1821,6 +1800,7 @@ static void
 hildon_home_area_child_save_position (ChildData *child, GKeyFile *keyfile)
 {
   const gchar  *id;
+  guint         width, height;
 
   if (!HILDON_DESKTOP_IS_HOME_ITEM (child->widget))
     return;
@@ -1828,6 +1808,18 @@ hildon_home_area_child_save_position (ChildData *child, GKeyFile *keyfile)
   id = hildon_desktop_item_get_id (HILDON_DESKTOP_ITEM (child->widget));
   g_return_if_fail (id);
 
+  width  = child->widget->allocation.width;
+  height = child->widget->allocation.height;
+
+  if (width == 1 && height == 1)
+  {
+    GtkRequisition req = {0};
+    /* If the child has not been allocated yet, use the size request ... */
+    gtk_widget_size_request (child->widget, &req);
+    width  = req.width;
+    height = req.height;
+  }
+
   g_key_file_set_integer (keyfile,
                           id,
                           HH_APPLET_KEY_X,
@@ -1846,12 +1838,12 @@ hildon_home_area_child_save_position (ChildData *child, GKeyFile *keyfile)
   g_key_file_set_integer (keyfile,
                           id,
                           HH_APPLET_KEY_WIDTH,
-                          child->widget->allocation.width);
+                          width);
 
   g_key_file_set_integer (keyfile,
                           id,
                           HH_APPLET_KEY_HEIGHT,
-                          child->widget->allocation.height);
+                          height);
 
 }
 
