@@ -114,12 +114,14 @@ static void
 hd_keys_action_close (HDKeysConfig *keys,
 		      gpointer     *user_data)
 {
+#if 0	
   HDWMWindow * win = hd_wm_get_active_window();
 
   if (win)
     hd_wm_window_close (win);
   else
     g_warning ("No active window set");
+#endif
 }
 
 static void
@@ -659,6 +661,8 @@ hd_keys_load_and_grab_all_shortcuts (HDKeysConfig *keys)
         keys->shortcuts = g_slist_append (keys->shortcuts, shortcut);
       }
     }
+
+    g_free (key_def_str);
     i++;
   }
 }
