@@ -38,10 +38,7 @@
 #include <hildon-widgets/hildon-note.h>
 #endif
 
-
-#define gettext(o) o
-#define dgettext(o,e) o
-#define _(o) o
+#include <glib/gi18n.h>
 
 #include "hd-wm.h"
 #include "hd-wm-application.h"
