@@ -122,6 +122,8 @@ struct _HDHomeWindowPrivate
   GtkWidget                    *cancel_note;
   guint                         background_loading_timeout;
   guint                         cancel_note_update_timeout;
+
+  guint                         kill_greeting_idle;
 };
 
 /* Properties */
@@ -592,6 +594,19 @@ hd_home_window_save_background (HDHomeWindow *window)
   g_free (conffile);
 }
 
+static gboolean
+kill_greeting (void)
+{
+  guint greeting_pid;
+
+  greeting_pid = pid_from_exec_name ("osso_startup_greeting");
+
+  if (greeting_pid > 0)
+    kill (greeting_pid, SIGUSR1);
+
+  return FALSE;
+}
+
 static void
 background_apply_callback (HildonDesktopBackground     *background,
                            Picture                      picture,
@@ -599,7 +614,6 @@ background_apply_callback (HildonDesktopBackground     *background,
                            HDHomeWindow                *window)
 {
   HDHomeWindowPrivate  *priv;
-  guint greeting_pid;
 
 #ifdef DEBUG
   g_debug ("Background applied!");
@@ -683,10 +697,8 @@ background_apply_callback (HildonDesktopBackground     *background,
     }
 
   /* If there's a process osso_startup_greeting, kill it with SIGUSR1. */
-  greeting_pid = pid_from_exec_name ("osso_startup_greeting"); 
-
-  if (greeting_pid > 0)
-    kill (greeting_pid, SIGUSR1);
+  if (!priv->kill_greeting_idle)
+    priv->kill_greeting_idle = g_idle_add ((GSourceFunc)kill_greeting, NULL);
 }
 
 static void
