@@ -2536,6 +2536,11 @@ hd_switcher_menu_notification_deleted_cb (HildonDesktopNotificationManager   *nm
                                           HDSwitcherMenu *switcher)
 {
   GList *children = NULL, *l;
+#ifdef HAVE_MCE  
+  GtkTreeIter iter;
+  GHashTable *hints;
+  GValue *hint;
+#endif
   
   children =
     hildon_desktop_popup_menu_get_children (switcher->priv->menu_notifications);    	  
@@ -2560,8 +2565,24 @@ hd_switcher_menu_notification_deleted_cb (HildonDesktopNotificationManager   *nm
         {
 	  hd_switcher_menu_reset_main_icon (switcher, TRUE);
 	  switcher->priv->blinking_notification = -1;
+
 	}
-	
+
+#ifdef HAVE_MCE  
+        if (hildon_desktop_notification_manager_find_by_id (switcher->nm, id, &iter))
+        {
+          gtk_tree_model_get (GTK_TREE_MODEL (switcher->nm),
+                              &iter,
+                              HD_NM_COL_HINTS, &hints,
+                              -1);
+
+          hint = g_hash_table_lookup (hints, "led-pattern");
+
+          if (hint)
+            hd_switcher_menu_set_led_pattern (g_value_get_string (hint), FALSE);
+        }
+#endif
+
         hildon_desktop_popup_menu_remove_item (switcher->priv->menu_notifications,
 	                                       menu_item);
 
